@@ -5,7 +5,7 @@ use strict;
 use warnings;
 ##use Mail::Milter::Authentication::Pragmas;
 # ABSTRACT: Common configuration handling
-our $VERSION = '3.20240205'; # VERSION
+our $VERSION = '3.20240618'; # VERSION
 use English;
 use JSON::XS;
 use TOML;
@@ -102,8 +102,8 @@ sub setup_config {
             die $type.'_dir is not a writable' if ! -w $dir;
         }
         else {
-            if ( $EUID == 0 ) {
-                # We are root, create in global space
+            if ( $EUID == 0 && -d "/var/$type" && -w "/var/$type" ) {
+                # We are root, create in global space if it exists and is writable
                 $dir = '/var/'.$type.'/authentication_milter';
                 mkdir $dir if ! -e $dir;
                 # Create the subdir for this IDENT
@@ -117,7 +117,7 @@ sub setup_config {
                 }
             }
             else {
-                # We are a user! Create something in a temporary space
+                # We are a user, or have no writable global space, Create something in a temporary space
                 $dir = join( '_',
                   '/tmp/authentication_milter',
                   $type,
@@ -127,6 +127,7 @@ sub setup_config {
                 mkdir $dir if ! -e $dir;
             }
         }
+        die "Generated ${type}_dir ($dir) could not be created, set or check ${type}_dir in config" unless -e $dir && -d $dir && -w $dir;
         $config->{$type.'_dir'} = $dir;
     }
 }
@@ -267,7 +268,7 @@ Mail::Milter::Authentication::Config - Load config files for Authentication Milt
 
 =head1 VERSION
 
-version 3.20240205
+version 3.20240618
 
 =head1 SYNOPSIS
 
